Page 141 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 141

Home

    face of the earth along this area because of their refusal
    to adopt and to embrace Marxist-Leninist philosophy.
    An example of the extent of the persecution can be
    illustrated by a 25 year old pastor by the name of Biardo,
    who was awakened early one morning when Sandinista
    troops came into his village. They called all of the men
    together outside the church, gave them shovels, had
    them dig their own graves, and shot them in the back.
    The women and children were taken inside the church,
    and there in front of Pastor Biardo they were violated
    and tortured in such ways that I cannot begin to describe

    to you today.

    The pastor was mocked, tied up to a pole, spat upon,
    and the Sandinista troops said, "Where is your God?
    Why doesn't He ever hear you? Why doesn't He ever
    answer your prayers?" They set the church on fire. The
    pastor was soon terribly burned on his arms, legs, his
    hands and feet; and a result of the fire was that the ropes
    that bound him were also burned through. He was then
    able to rescue some of the people inside the church.
    They made their way through the jungle, hiding in the
    daytime, and traveling at night, in what has come to be
    known as The Trail of Tears, to one of the refugee
    camps along the Honduras Nicaragua border inside
    Honduras. That is but one example of the persecution of
    the church in Nicaragua.'”

    The story of Africa is another story of the betrayal of
    an entire continent into the hands of those who hate

    Christianity. Out of 52 nations, the vast majority are
    ruled by one-party dictatorships with no chance for
    democratic reforms. The truth about these betrayals, and
    the resulting war against religion, has been withheld by

    136

    The Secret Side of History